(window.webpackJsonp=window.webpackJsonp||[]).push([[103],{228:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"lb",fields:{year:{displayName:"Joer",relative:{0:"dëst Joer",1:"nächst Joer","-1":"lescht Joer"},relativeTime:{future:{one:"an {0} Joer",other:"a(n) {0} Joer"},past:{one:"virun {0} Joer",other:"viru(n) {0} Joer"}}},"year-short":{displayName:"J.",relative:{0:"dëst Joer",1:"nächst Joer","-1":"lescht Joer"},relativeTime:{future:{one:"an {0} J.",other:"a(n) {0} J."},past:{one:"virun {0} J.",other:"viru(n) {0} J."}}},"year-narrow":{displayName:"J.",relative:{0:"dëst Joer",1:"nächst Joer","-1":"lescht Joer"},relativeTime:{future:{one:"+{0} J.",other:"+{0} J."},past:{one:"-{0} J.",other:"-{0} J."}}},quarter:{displayName:"Quartal",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{one:"an {0} Quartal",other:"a(n) {0} Quartaler"},past:{one:"virun {0} Quartal",other:"viru(n) {0} Quartaler"}}},"quarter-short":{displayName:"Q.",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{one:"an {0} Q.",other:"a(n) {0} Q."},past:{one:"virun {0} Q.",other:"viru(n) {0} Q."}}},"quarter-narrow":{displayName:"Q.",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{one:"+{0} Q.",other:"+{0} Q."},past:{one:"-{0} Q.",other:"-{0} Q."}}},month:{displayName:"Mount",relative:{0:"dëse Mount",1:"nächste Mount","-1":"leschte Mount"},relativeTime:{future:{one:"an {0} Mount",other:"a(n) {0} Méint"},past:{one:"virun {0} Mount",other:"viru(n) {0} Méint"}}},"month-short":{displayName:"M.",relative:{0:"dëse Mount",1:"nächste Mount","-1":"leschte Mount"},relativeTime:{future:{one:"an {0} M.",other:"a(n) {0} M."},past:{one:"virun {0} M.",other:"viru(n) {0} M."}}},"month-narrow":{displayName:"M.",relative:{0:"dëse Mount",1:"nächste Mount","-1":"leschte Mount"},relativeTime:{future:{one:"+{0} M.",other:"+{0} M."},past:{one:"-{0} M.",other:"-{0} M."}}},week:{displayName:"Woch",relative:{0:"dës Woch",1:"nächst Woch","-1":"lescht Woch"},relativeTime:{future:{one:"an {0} Woch",other:"a(n) {0} Wochen"},past:{one:"virun {0} Woch",other:"viru(n) {0} Wochen"}},relativePeriod:"the week of {0}"},"week-short":{displayName:"W.",relative:{0:"dës Woch",1:"nächst Woch","-1":"lescht Woch"},relativeTime:{future:{one:"an {0} W.",other:"a(n) {0} W."},past:{one:"virun {0} W.",other:"viru(n) {0} W."}},relativePeriod:"the week of {0}"},"week-narrow":{displayName:"W.",relative:{0:"dës Woch",1:"nächst Woch","-1":"lescht Woch"},relativeTime:{future:{one:"+{0} W.",other:"+{0} W."},past:{one:"-{0} W.",other:"-{0} W."}},relativePeriod:"the week of {0}"},day:{displayName:"Dag",relative:{0:"haut",1:"muer","-1":"gëschter"},relativeTime:{future:{one:"an {0} Dag",other:"a(n) {0} Deeg"},past:{one:"virun {0} Dag",other:"viru(n) {0} Deeg"}}},"day-short":{displayName:"D.",relative:{0:"haut",1:"muer","-1":"gëschter"},relativeTime:{future:{one:"an {0} D.",other:"a(n) {0} D."},past:{one:"virun {0} D.",other:"viru(n) {0} D."}}},"day-narrow":{displayName:"D.",relative:{0:"haut",1:"muer","-1":"gëschter"},relativeTime:{future:{one:"+{0} D.",other:"+{0} D."},past:{one:"-{0} D.",other:"-{0} D."}}},hour:{displayName:"Stonn",relative:{0:"this hour"},relativeTime:{future:{one:"an {0} Stonn",other:"a(n) {0} Stonnen"},past:{one:"virun {0} Stonn",other:"viru(n) {0} Stonnen"}}},"hour-short":{displayName:"St.",relative:{0:"this hour"},relativeTime:{future:{one:"an {0} St.",other:"a(n) {0} St."},past:{one:"virun {0} St.",other:"viru(n) {0} St."}}},"hour-narrow":{displayName:"St.",relative:{0:"this hour"},relativeTime:{future:{one:"+{0} St.",other:"+{0} St."},past:{one:"-{0} St.",other:"-{0} St."}}},minute:{displayName:"Minutt",relative:{0:"this minute"},relativeTime:{future:{one:"an {0} Minutt",other:"a(n) {0} Minutten"},past:{one:"virun {0} Minutt",other:"viru(n) {0} Minutten"}}},"minute-short":{displayName:"Min.",relative:{0:"this minute"},relativeTime:{future:{one:"an {0} Min.",other:"a(n) {0} Min."},past:{one:"virun {0} Min.",other:"viru(n) {0} Min."}}},"minute-narrow":{displayName:"Min.",relative:{0:"this minute"},relativeTime:{future:{one:"+{0} Min.",other:"+{0} Min."},past:{one:"-{0} Min.",other:"-{0} Min."}}},second:{displayName:"Sekonn",relative:{0:"now"},relativeTime:{future:{one:"an {0} Sekonn",other:"a(n) {0} Sekonnen"},past:{one:"virun {0} Sekonn",other:"viru(n) {0} Sekonnen"}}},"second-short":{displayName:"Sek.",relative:{0:"now"},relativeTime:{future:{one:"an {0} Sek.",other:"a(n) {0} Sek."},past:{one:"virun {0} Sek.",other:"viru(n) {0} Sek."}}},"second-narrow":{displayName:"Sek.",relative:{0:"now"},relativeTime:{future:{one:"+{0} Sek.",other:"+{0} Sek."},past:{one:"-{0} Sek.",other:"-{0} Sek."}}}}})}}]);
//# sourceMappingURL=103.aaedf07e1a1c0392f425.index.js.map